import React, { useEffect, useState } from 'react'
import Taro from '@tarojs/taro'
import { Canvas, View } from '@tarojs/components'
import rtLog from '@/utils/rtLog'
import { getConfig, getCanvas } from './sdk'

export default (props) => {
  const { poster, miniCode, name, desc = '长按识别在线看房', onStart, onEnd } = props

  const [posterData, setPosterData] = useState()
  const [codeData, setCodeData] = useState()
  const [canvas, setCanvas] = useState()

  useEffect(() => {
    Taro.nextTick(() => {
      getCanvas('#canvas-poster').then(setCanvas)
    })
  }, [])

  useEffect(() => {
    if (poster) {
      Taro.downloadFile({
        url: poster,
        success: (res) => {
          if (res.statusCode === 200) {
            setPosterData(res.tempFilePath)
          }
        },
        fail: (err) => {
          rtLog.error(err)
          Taro.showToast({
            title: '下载海报图出错',
            icon: 'none',
          })
        }
      })
    }
  }, [poster])
  
  useEffect(() => {
    if (miniCode) {
      Taro.downloadFile({
        url: miniCode,
        success: (res) => {
          if (res.statusCode === 200) {
            setCodeData(res.tempFilePath)
          }
        },
        fail: (err) => {
          rtLog.error(err)
          Taro.showToast({
            title: '下载海报二维码出错',
            icon: 'none',
          })
        }
      })
    }
  }, [miniCode])

  useEffect(() => {
    if (canvas && posterData && codeData) {
      onStart()
      const config = getConfig()
      const dpr = config.systemInfo.pixelRatio
      const ctx = canvas.getContext('2d')
      canvas.width = config.canvas.width
      canvas.height = config.canvas.height
      ctx.scale(dpr, dpr)

      //
    }
  }, [canvas, posterData, codeData, onStart, onEnd])

  return <View style={{width: 0, height: 0}}><Canvas type='2d' id='canvas-poster' /></View>
}
