import Taro from '@tarojs/taro'

/**
 * 获取配置
 * @returns 
 */
export function getConfig() {
  // https://developers.weixin.qq.com/miniprogram/dev/api/base/system/wx.getSystemInfo.html
  const systemInfo = Taro.getStorageSync('systemInfo')
  const { windowWidth, pixelRatio } = systemInfo

  // canvas
  const canvas = {
    width: windowWidth * pixelRatio,
    // 设计稿宽高比 2.16  = height / width
    height: windowWidth * pixelRatio * 2.16,
  }

  // 图片
  const image = {
    width: canvas.width,
    height: canvas.width * 16 / 9, // 图片宽高 9 : 16
    x: 0,
    y: 0,
  }

  // 头像
  const avatar = {
    width: 88,
    height: 88,
    x: 30,
    y: image.height + 50,
  }

  // 小程序码
  const miniCode = {
    width: 132,
    height: 132,
    x: canvas.width - 132 - 30,  // 128 是宽度, 30 是右边距
    y: image.height + 50,
  }

  // 姓名
  const name = {
    // https://developer.mozilla.org/zh-CN/docs/Web/CSS/font
    font: '28px',
    // https://developer.mozilla.org/zh-CN/docs/Web/API/CanvasRenderingContext2D/fillStyle
    fillStyle: '#333333',

    // 60 是头像左边距 + 小程序码右边距
    // 40 是文字距离头像的左边距 20 + 距离小程序码的右边距 20
    maxWidth: canvas.width - 60 - avatar.width - miniCode.width - 40,

    x: image.height + 66,
    // 30 是头像左边距, 20 文字距离头像的左边距
    y: 30 + avatar.width + 20,
  }

  // 说明
  const desc = {
    font: '20px',
    fillStyle: '#666666',
    maxWidth: name.maxWidth,
    x: name.x,
    y: image.height + 106,
  }

  return {
    systemInfo,
    canvas,
    image,
    miniCode,
    name,
    desc,
  }
}

/**
 * 绘制图像
 * @param {*} ctx 
 * @param {*} image 
 * @param {*} config 
 */
export function drawImage(ctx, image, config) {
  ctx.drawImage(image, config.x, config.y, config.width, config.height)
}

/**
 * 绘制文字
 * @param {*} ctx 
 * @param {*} text 
 * @param {*} config 
 */
export function darwText(ctx, text, config) {
  ctx.setFillStyle(config.fillStyle)
  ctx.font = config.font
  ctx.fillText(text, config.x, config.y, config.maxWidth)
}

/**
 * 获取 canvas
 * @param {*} selector 
 * @returns 
 */
export function getCanvas(selector) {
  return new Promise((resolve) => {
    const query = Taro.createSelectorQuery()
    query.select(selector)
      .node((res) => resolve(res.node))
      .exec()
  })
}
